@@ -15,15 +15,15 @@ my $ab  = 'ab -t 1 -c 10 -k';
 my $url = 'http://127.0.0.1/';
 
 my @try = (
-    [ 'AnyEvent' ],
     [ 'AnyEvent::HTTPD' ],
-    [ 'Standalone' ],
-    [ 'Standalone', max_workers => 10 ],
+    [ 'HTTP::Server::PSGI' ],
+    [ 'HTTP::Server::PSGI', ' (workers=10)', max_workers => 10 ],
+    [ 'Twiggy' ],
     [ 'HTTP::Server::Simple' ],
-    [ 'Coro' ],
+    [ 'Corona' ],
     [ 'Danga::Socket' ],
-    [ 'POE' ],
-    [ 'Nomo' ],
+    [ '+POE::Component::Server::PSGI' ],
+    [ 'Starman', ' (workers=10)', workers => 10 ],
 );
 
 my @backends;
@@ -56,8 +56,8 @@ EOF
 }
 
 sub run_one {
-    my($server_class, @args) = @_;
-    print "-- server: $server_class\n";
+    my($server_class, $how, @args) = @_;
+    print "-- server: $server_class ", ($how || ''), "\n";
 
     test_tcp(
         client => sub {
@@ -65,6 +65,7 @@ sub run_one {
             my $uri = URI->new($url);
             $uri->port($port);
             $uri = shell_quote($uri);
+            system "ab -n 20 $uri > /dev/null"; # warmup
             print `$ab $uri | grep 'Requests per '`;
         },
         server => sub {
