@@ -25,7 +25,7 @@ __END__
 
 =head1 NAME
 
-Plack::Handler::HTTP::Server::PSGI - adapter for HTTP:::Server::PSGI
+Plack::Handler::HTTP::Server::PSGI - adapter for HTTP::Server::PSGI
 
 =head1 SYNOPSIS
 
@@ -80,4 +80,8 @@ Kazuho Oku
 
 Tatsuhiko Miyagawa
 
+=head1 SEE ALSO
+
+L<Plack> L<HTTP::Server::PSGI>
+
 =cut
